@@ -1,33 +1,39 @@
 from wordpress_xmlrpc.base import *
-from wordpress_xmlrpc.mixins import *
-from wordpress_xmlrpc.wordpress import WordPressPost
+from wordpress_xmlrpc.wordpress import WordPressPost, WordPressPostType
 
 
-class GetRecentPosts(AuthenticatedMethod):
+class GetPosts(AuthenticatedMethod):
     """
-    Retrieve most recent posts from the blog.
+    Retrieve posts from the blog.
 
     Parameters:
-        `num_posts`: Number of blog posts to return.
+       `filter`: optional `dict` of filters:
+            * `number`
+            * `offset`
+            * `orderby`
+            * `order`: 'ASC' or 'DESC'
+            * `post_type`: Defaults to 'post'
+            * `post_status`
 
-    Returns: `list` of `WordPressPost` instances.
+    Returns: `list` of :class:`WordPressPost` instances.
     """
-    method_name = 'metaWeblog.getRecentPosts'
-    method_args = ('num_posts',)
+    method_name = 'wp.getPosts'
+    optional_args = ('filter', 'fields')
     results_class = WordPressPost
 
 
-class GetPost(AuthParamsOffsetMixin, AuthenticatedMethod):
+class GetPost(AuthenticatedMethod):
     """
     Retrieve an individual blog post.
 
     Parameters:
         `post_id`: ID of the blog post to retrieve.
 
-    Returns: `WordPressPost` instance.
+    Returns: :class:`WordPressPost` instance.
     """
-    method_name = 'metaWeblog.getPost'
+    method_name = 'wp.getPost'
     method_args = ('post_id',)
+    optional_args = ('fields',)
     results_class = WordPressPost
 
 
@@ -36,31 +42,29 @@ class NewPost(AuthenticatedMethod):
     Create a new post on the blog.
 
     Parameters:
-        `content`: A `WordPressPost` instance with at least the `title` and `description` values set.
-        `publish`: Boolean indicating whether the blog post should be published upon creation.
+        `content`: A :class:`WordPressPost` instance with at least the `title` and `content` values set.
 
     Returns: ID of the newly-created blog post (an integer).
     """
-    method_name = 'metaWeblog.newPost'
-    method_args = ('content', 'publish')
+    method_name = 'wp.newPost'
+    method_args = ('content',)
 
 
-class EditPost(AuthParamsOffsetMixin, AuthenticatedMethod):
+class EditPost(AuthenticatedMethod):
     """
     Edit an existing blog post.
 
     Parameters:
         `post_id`: ID of the blog post to edit.
-        `content`: A `WordPressPost` instance with the new values for the blog post.
-        `publish`: Boolean indicating whether the blog post should be published upon being updated.
+        `content`: A :class:`WordPressPost` instance with the new values for the blog post.
 
     Returns: `True` on successful edit.
     """
-    method_name = 'metaWeblog.editPost'
-    method_args = ('post_id', 'content', 'publish')
+    method_name = 'wp.editPost'
+    method_args = ('post_id', 'content')
 
 
-class DeletePost(BloggerApiMethodMixin, AuthParamsOffsetMixin, AuthenticatedMethod):
+class DeletePost(AuthenticatedMethod):
     """
     Delete a blog post.
 
@@ -69,7 +73,7 @@ class DeletePost(BloggerApiMethodMixin, AuthParamsOffsetMixin, AuthenticatedMeth
 
     Returns: `True` on successful deletion.
     """
-    method_name = 'blogger.deletePost'
+    method_name = 'wp.deletePost'
     method_args = ('post_id', )
 
 
@@ -112,14 +116,62 @@ class GetPostFormats(AuthenticatedMethod):
         return args
 
 
-class PublishPost(AuthParamsOffsetMixin, AuthenticatedMethod):
+class GetPostTypes(AuthenticatedMethod):
     """
-    Mark a blog post as published.
+    Retrieve a list of post types used by the blog.
 
     Parameters:
-        `post_id`: ID of the blog post to publish.
+        None
 
-    Returns: ID of the published blog post.
+    Returns: `dict` with names as keys and :class:`WordPressPostType` instances as values.
     """
-    method_name = 'mt.publishPost'
+    method_name = 'wp.getPostTypes'
+    results_class = WordPressPostType
+
+    def process_result(self, raw_result):
+        result = {}
+        for name, raw_value in raw_result.items():
+            result[name] = self.results_class(raw_value)
+        return result
+
+
+class GetPostType(AuthenticatedMethod):
+    """
+    Retrieve an individual blog post type.
+
+    Parameters:
+        `post_type`: Name of the blog post type to retrieve.
+
+    Returns: :class:`WordPressPostType` instance.
+    """
+    method_name = 'wp.getPostType'
+    method_args = ('post_type',)
+    results_class = WordPressPostType
+
+
+class GetRevisions(AuthenticatedMethod):
+    """
+    Retrieve all revisions of a post.
+
+    Parameters:
+        `post_id`: ID of the post.
+
+    Returns: `list` of :class:`WordPressPost` instances.
+    """
+    method_name = 'wp.getRevisions'
     method_args = ('post_id',)
+    optional_args = ('fields',)
+    results_class = WordPressPost
+
+
+class RestoreRevision(AuthenticatedMethod):
+    """
+    Restores a post to a previous revision.
+
+    Parameters:
+        `revision_id`: ID of the revision to revert to.
+
+    Returns: `True` on successful reversion.
+    """
+    method_name = 'wp.restoreRevision'
+    method_args = ('revision_id',)
